@@ -26,8 +26,12 @@ class DjangoResponse(BaseResponse):
         self.original = response
         self.parser_checked = False
 
+    def set_html_content(self, content):
+        self.response.content = content
+        self.set_header('Content-Type', 'text/html')
+
     def set_cookie(self, key: str, value: str = "", max_age: int = None, expires: int = None, path: str = "/",
-                   domain: str = None, secure: bool = False, httponly: bool = False, samesite: str = "Lax"):
+                   domain: str = None, secure: bool = False, httponly: bool = False, samesite: str = "lax"):
         self.response.set_cookie(
             key,
             value,
