@@ -14,6 +14,7 @@
 from typing import Union
 
 from supertokens_python.framework.request import BaseRequest
+from urllib.parse import parse_qsl
 
 
 class FastApiRequest(BaseRequest):
@@ -27,7 +28,10 @@ class FastApiRequest(BaseRequest):
         return self.request.query_params.get(key, default)
 
     async def json(self):
-        return await self.request.json()
+        try:
+            return await self.request.json()
+        except Exception:
+            return {}
 
     def method(self) -> str:
         return self.request.method
@@ -50,3 +54,6 @@ class FastApiRequest(BaseRequest):
 
     def get_path(self) -> str:
         return self.request.url.path
+
+    async def form_data(self):
+        return dict(parse_qsl((await self.request.body()).decode('utf-8')))
