@@ -68,13 +68,18 @@ def normalise_session_scope(recipe: SessionRecipe, session_scope: str) -> str:
 def normalise_same_site(same_site: str) -> str:
     same_site = same_site.strip()
     same_site = same_site.lower()
-    allowed_values = {'Strict', 'Lax', 'None'}
+    allowed_values = {'strict', 'lax', 'none'}
     if same_site not in allowed_values:
         raise Exception(
-            'cookie same site must be one of "Strict", "Lax", or "None"')
+            'cookie same site must be one of "strict", "lax", or "none"')
     return same_site
 
 
+def get_url_scheme(url) -> str:
+    url_obj = urlparse(url)
+    return url_obj.scheme
+
+
 def get_top_level_domain_for_same_site_resolution(url: str) -> str:
     url_obj = urlparse(url)
     hostname = url_obj.hostname
@@ -187,7 +192,10 @@ def validate_and_normalise_user_input(
         app_info.api_domain.get_as_string_dangerous())
     top_level_website_domain = get_top_level_domain_for_same_site_resolution(
         app_info.website_domain.get_as_string_dangerous())
-    cookie_same_site = 'None' if top_level_api_domain != top_level_website_domain else 'Lax'
+
+    api_domain_scheme = get_url_scheme(app_info.api_domain.get_as_string_dangerous())
+    website_domain_scheme = get_url_scheme(app_info.website_domain.get_as_string_dangerous())
+    cookie_same_site = 'None' if (top_level_api_domain != top_level_website_domain) or (api_domain_scheme != website_domain_scheme) else 'Lax'
     if 'cookie_same_site' in config:
         cookie_same_site = normalise_same_site(config['cookie_same_site'])
 
