@@ -97,7 +97,7 @@ def manage_cookies_post_response(session: Session, response: BaseResponse):
                 response,
                 session['user_id'],
                 access_token['expiry'],
-                session['jwt_payload']
+                session['access_token_payload']
             )
         refresh_token = session['new_refresh_token_info']
         if refresh_token is not None:
@@ -285,6 +285,9 @@ class Supertokens:
             return None
         else:
             request_rid = get_rid_from_request(request)
+            if request_rid is not None and request_rid == 'anti-csrf':
+                # see https://github.com/supertokens/supertokens-python/issues/54
+                request_rid = None
             request_id = None
             matched_recipe = None
             if request_rid is not None:
@@ -311,13 +314,13 @@ class Supertokens:
 
     async def handle_supertokens_error(self, request: BaseRequest, err: SuperTokensError, response: BaseResponse):
         if isinstance(err, GeneralError):
-            return send_non_200_response(str(err), 500, response)
+            raise err
 
         if isinstance(err, BadInputError):
             return send_non_200_response(str(err), 400, response)
 
         for recipe in self.recipe_modules:
-            if recipe.is_error_from_this_or_child_recipe_based_on_instance(
+            if recipe.is_error_from_this_recipe_based_on_instance(
                     err):
                 return await recipe.handle_error(request, err, response)
         raise err
